@@ -444,7 +444,9 @@ class Human:
     @staticmethod
     def calculate_mouth(ai_crop_point_dict):
         """
-        根据 眼镜 鼻子 计算嘴巴的位置
+        1.根据 眼镜 鼻子 计算嘴巴的位置
+        2.根据眼睛鼻子判断 头顶是否要删除
+        3.根据脚踝判断 脚底是否要删除
         """
         # y: 鼻子的y + (鼻子的y - 眼睛最低的y)
         # x: 鼻子的x
@@ -457,6 +459,13 @@ class Human:
                 'top_site': (nose_x, mouth_y),
                 'bottom_site': (nose_x, mouth_y)
             }
+        if 'eye' not in ai_crop_point_dict.keys() and 'nose' not in ai_crop_point_dict.keys() \
+                and 'human_top' in ai_crop_point_dict.keys():
+            ai_crop_point_dict.pop('human_top')
+
+        if 'ankle' not in ai_crop_point_dict.keys() and 'human_bottom' in ai_crop_point_dict.keys():
+            ai_crop_point_dict.pop('human_bottom')
+
         return ai_crop_point_dict
 
     @staticmethod
@@ -556,28 +565,27 @@ class Human:
             # 不分左右的点 腰 pel、脊柱 spi
             # 1.置信度够
             # 2.在裁剪范围内
-            pel_h = pel[1]/self.image_height
-            pel_w = pel[0]/self.image_width
+            pel_h = pel[1] / self.image_height
+            pel_w = pel[0] / self.image_width
             if pel[2] >= confidence and crop_top <= pel_h <= crop_bottom:
                 valid_point_list.append(pel_w)
 
-            spi_h = spi[1]/self.image_height
-            spi_w = spi[0]/self.image_width
+            spi_h = spi[1] / self.image_height
+            spi_w = spi[0] / self.image_width
             if spi[2] >= confidence and crop_top <= spi_h <= crop_bottom:
                 valid_point_list.append(spi_w)
 
             # 分左右的点 左臀 l_hip、右臀 r_hip
             # 1. 左右点置信度都够
             # 2. 有一个点的 上下在裁剪范围内
-            l_hip_h = l_hip[1]/self.image_height
-            r_hip_h = r_hip[1]/self.image_height
-            l_hip_w = l_hip[0]/self.image_width
-            r_hip_w = r_hip[0]/self.image_width
+            l_hip_h = l_hip[1] / self.image_height
+            r_hip_h = r_hip[1] / self.image_height
+            l_hip_w = l_hip[0] / self.image_width
+            r_hip_w = r_hip[0] / self.image_width
 
             if l_hip[2] >= confidence and r_hip[2] >= confidence and \
                     (crop_top <= l_hip_h <= crop_bottom or crop_top <= r_hip_h <= crop_bottom):
-
-                hip_w = l_hip_w + (r_hip_w - l_hip_w)/2
+                hip_w = l_hip_w + (r_hip_w - l_hip_w) / 2
 
                 valid_point_list.append(hip_w)
 
@@ -592,7 +600,6 @@ class Human:
         # 多人 取多人的中点
         return sum(all_human_center) / len(all_human_center)
 
-
     def add_new_crop_point(self, recognition, human_pose):
         """
         把 recognition 内的数据 添加到 旧版的17个人体关键点的数据结构中
