@@ -10,8 +10,16 @@ class ShouldIndex:
             'crop_head': {'status': False},
             'get_crop_point': {'status': False},
             'slot_and_img_ration': {'offset': 1},
+            'expected_crop_result': False,
+            # 上下padding 留了多少
+            'top_padding_ratio': 0,
+            'bottom_padding_ratio': 0,
         }
 
+    def expected_crop_result(self):
+        if self.crop_indexing_dict['get_crop_point']['status']:
+            self.crop_indexing_dict['expected_crop_result'] = True
+
     def extension(self):
         self.crop_indexing_dict['extension'] = {
             'status': True
@@ -79,6 +87,22 @@ class ShouldIndex:
             'status': True if origin_crop_site == crop_site else False,
         }
 
+    def get_top_and_bottom_padding(self, top, padding_top, bottom, padding_bottom):
+        """获取 上下 padding占比 """
+        if top >= padding_top:
+            top_padding_ratio = 1
+        else:
+            top_padding_ratio = top / padding_top
+        self.crop_indexing_dict['top_padding_ratio'] = top_padding_ratio
+
+        if bottom + padding_bottom <= 1:
+            bottom_padding_ratio = 1
+        else:
+            bottom_padding_ratio = (1 - bottom) / padding_bottom
+
+        self.crop_indexing_dict['bottom_padding_ratio'] = bottom_padding_ratio
+
+
     def crop_head(self):
         """裁剪头"""
         self.crop_indexing_dict['crop_head'] = {
@@ -115,7 +139,6 @@ class ImageCrop:
         """
         需求文档： https://www.teambition.com/task/619e01f619f251003f289802
         """
-
         slot_width = slot_config.get('width')
         slot_height = slot_config.get('height')
         crop_info = slot_config.get(CROP)
@@ -130,12 +153,14 @@ class ImageCrop:
         need_crop = crop_info.get(NEED_CROP)
         if not need_crop:
             self.si.get_crop_site([None, None], [None, None])
+            self.si.expected_crop_result()
             return self._need_center_crop(crop_method, slot_width, slot_height, img)
 
         # 槽是否设置对应图片类型的裁剪规则
         crop_parameter = crop_info.get(img.img_crop_type, {})
         if not crop_parameter:
             self.si.get_crop_site([None, None], [None, None])
+            self.si.expected_crop_result()
             # print(f"居中裁剪： 未获取到裁剪参数，图片类型为 {img.image_classification}")
             return self._need_center_crop(crop_method, slot_width, slot_height, img)
 
@@ -152,7 +177,7 @@ class ImageCrop:
         x_center_method = crop_info.get(X_CENTER_METHOD, "human_center")
 
         # 寻找上下裁剪点
-        top, bottom, left, right = self._get_top_bottom_crop_point(crop_parameter, img, x_center_method)
+        top, bottom, left, right = self._get_top_bottom_crop_point(crop_parameter, img, x_center_method, crop_method)
 
         # 计算 内边距
         padding_unit = crop_parameter.get(PADDING_UNIT, 'pi')  # 'percent pe' 'pixel pi'
@@ -172,6 +197,8 @@ class ImageCrop:
         y1 = max(top - padding_top, 0)
         y2 = min(bottom + padding_bottom, 1)
 
+        self.si.get_top_and_bottom_padding(top, padding_top, bottom, padding_bottom)
+
         if crop_method == 'w':  # 自适应裁剪，slot宽不变,高可以改变
             # 保留上下 y ，还是保留左右居中 x
             retain_x_or_y = crop_info.get(RETAIN_X_OR_Y, "y")
@@ -236,10 +263,10 @@ class ImageCrop:
                 x = self._alternative_center(x_center, slot_width, transform_img_width)
 
                 self.si.main_part_offset(x * img.width + slot_width / scale_x / 2, x_center * img.width, 'x')
+                self.si.expected_crop_result()
 
             else:
-
-                width_scale = slot_width / ((x2 - x1) * img.width)
+                width_scale = slot_width / img.width
                 y = y1
                 # 保留上下，还是保留左右  human_center human_and_cloth brand
                 retain_x_or_y = crop_info.get(RETAIN_X_OR_Y, "x")
@@ -416,8 +443,10 @@ class ImageCrop:
         tag_1 = (left >= 0)
         tag_2 = (right <= transform_img_width)
 
-        if not (tag_1 and tag_2):
+        if not (tag_1 and tag_2):  # 一个不满足就需要扩边
             self.si.extension()
+        self.si.expected_crop_result()
+
         x = (center * transform_img_width - origin_slot_width / 2)
         # 调整 左右 扩边留白相等
         if tag_1 and tag_2:  # 左右 都有足够 预留范围 不用调整
@@ -449,7 +478,7 @@ class ImageCrop:
         amend_layout_height = 0
         return crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height, img.width, img.height
 
-    def _get_top_bottom_crop_point(self, crop_parameter, img, x_center_method):
+    def _get_top_bottom_crop_point(self, crop_parameter, img, x_center_method, crop_method):
         #  寻找 裁剪点
 
         if img.img_crop_type == BRAND:  # 资质图
@@ -460,6 +489,7 @@ class ImageCrop:
             crop_bottom = crop_bottom_site[1]
             crop_left = crop_top_site[0]
             crop_right = crop_bottom_site[0]
+            self.si.get_crop_site(['brand_top', 'brand_bottom'], ['brand_top', 'brand_bottom'])
 
         elif img.img_crop_type == TILE:  # 平铺图
             crop_top_site = img.crop_point.get('garment_top',
@@ -471,7 +501,7 @@ class ImageCrop:
             crop_bottom = crop_bottom_site[1]
             crop_left = crop_top_site[0]
             crop_right = crop_bottom_site[0]
-
+            self.si.get_crop_site(['garment_top', 'garment_bottom'], ['garment_top', 'garment_bottom'])
         else:  # 模特图
             top_site = crop_parameter.get(TOP_SITE)
             bottom_site = crop_parameter.get(BOTTOM_SITE)
@@ -481,6 +511,8 @@ class ImageCrop:
             crop_top_site, crop_top_name = self._from_img_get_top_site(img.crop_point, top_site)
             crop_bottom_site, crop_bottom_name = self._from_img_get_bottom_site(img.crop_point, bottom_site)
 
+            self.si.get_crop_site([top_site, bottom_site], [crop_top_name, crop_bottom_name])
+
             crop_top = crop_top_site[1]
             crop_bottom = crop_bottom_site[1]
 
